@@ -1,40 +1,36 @@
 /*
  *   MediaMVP Server
  *
- *   (C) 2003 Dominic Morris
+ *   (C) 2004 Dominic Morris
  *
- *   $Id: menu.c,v 1.11 2004/01/19 21:52:00 dom Exp $
- *   $Date: 2004/01/19 21:52:00 $
+ *   $Id: menu.c,v 1.18 2004/04/22 18:36:24 dom Exp $
+ *   $Date: 2004/04/22 18:36:24 $
  *
  *
  *   Constructs a menu and all such things
  *
  */
 
-#ifdef __cplusplus
-extern "C" {
-#endif
 
-#include "app.h"
+#include "program.h"
 
 
-/* Number of rows we can display on the menu */
 
-#define BLACK   0x00, 0x00, 0x00
-#define RED     0xFC, 0x14, 0x14
-#define GREEN   0x24, 0xFC, 0x24
-#define YELLOW  0xFC, 0xC0, 0x24
-#define BLUE    0x00, 0x00, 0xFC
-#define CYAN    0x00, 0xFC, 0xFC
-#define MAGENTA 0xB0, 0x00, 0xFC
-#define WHITE   0xFC, 0xFC, 0xFC
+#define BLACK   0x00000000
+#define RED     0x00FC1414
+#define GREEN   0x0024FC24
+#define YELLOW  0x00FCC024
+#define BLUE    0x000000FC
+#define CYAN    0x0000FCFC
+#define MAGENTA 0x00B000FC
+#define WHITE   0x00FCFCFC
 
 
 typedef struct {
     char    *name;
-    int    (*callback_func)(menu_t *menu,void *app, int sel);
+    int    (*callback_func)(menu_t *menu,void *program, int sel);
     int      num_options;
-    char   **options;
+    char const   **options;
     int      type;
     void    *value_ptr;
 } option_t;
@@ -43,7 +39,7 @@ typedef struct {
 struct _menu {
     dongle_t     *dongle;
     render_t     *render;
-    app_t        *app;
+    program_t        *program;
     void         *param;
     int           numoptions;
     option_t     *options;
@@ -57,6 +53,9 @@ struct _menu {
     menu_t        *child;
     char          *colours[4];   
     int          (*colour_func)(menu_t *menu,void *param, int key, int sel);
+    int		(*dialcode_func)(menu_t *menu, void *param, int key, int sel);
+    char	*current_dialcode;
+    int		current_dialcode_selection;
 };
 
 #define MENU_ROWS(menu)  ((menu)->maxrows -  4)
@@ -65,13 +64,13 @@ static int        menu_keys(void *ptr, int code);
 
 
 
-menu_t *new_menu(dongle_t *dongle,render_t *render, app_t *app,menu_t *parent, void *param, int flags)
+menu_t *new_menu(dongle_t *dongle,render_t *render, program_t *program,menu_t *parent, void *param, int flags)
 {
     menu_t       *menu = (menu_t *)malloc(sizeof(*menu));
 
     menu->dongle = dongle;
     menu->render = render;
-    menu->app    = app;
+    menu->program    = program;
     menu->param  = param;
     menu->title  = NULL;
     menu->top_offset = 0;
@@ -92,6 +91,9 @@ menu_t *new_menu(dongle_t *dongle,render_t *render, app_t *app,menu_t *parent, v
     menu->child = NULL;
     menu->param_clearup = NULL;
     menu->colour_func = NULL;
+    menu->dialcode_func = NULL;
+    menu->current_dialcode = NULL;
+    menu->current_dialcode_selection = 0;
 
     return menu;
 }
@@ -112,6 +114,15 @@ void delete_menu_tree(menu_t *menu)
 
 }
 
+void menu_free_dialcode(menu_t *menu)
+{
+    if(menu->current_dialcode) {
+        free(menu->current_dialcode);
+        menu->current_dialcode = NULL;
+    }
+}
+
+
 void delete_menu(menu_t *menu)
 {
     int     i;
@@ -139,10 +150,19 @@ void delete_menu(menu_t *menu)
         menu->colours[i] = NULL;
     }
 
+    /* Delete us from the parent if we've not been replaced... */
+    if ( menu->parent ) {
+        if ( menu->parent->child == menu ) {
+            menu->parent->child = NULL;
+        }
+    }
+
+    menu_free_dialcode(menu);
+
     free(menu);
 }
 
-void menu_set_title(menu_t *menu, char *text)
+void menu_set_title(menu_t *menu, const char *text)
 {
     if ( menu->title ) {
         free(menu->title);
@@ -151,9 +171,41 @@ void menu_set_title(menu_t *menu, char *text)
     menu->title = strdup(text);
 }
 
+void menu_init_dialcode(menu_t *menu, int length)
+{
+    menu_free_dialcode(menu);
+    menu->current_dialcode = (char *)malloc(length + 1);
+    memset(menu->current_dialcode, 0, length + 1);
+}
 
-void menu_add_option(menu_t *menu, char *name, int (callback_func)(menu_t *menu,void *param, int sel),
-                     int type, int num_options, char **options, void *value_ptr)
+char *menu_get_dialcode(menu_t *menu)
+{
+    return menu->current_dialcode;
+}
+
+void menu_set_dialcode(menu_t *menu, char *dialcode)
+{
+    menu_free_dialcode(menu);
+    menu->current_dialcode = (char *)strdup(dialcode);
+}
+
+int menu_get_dialcode_selection(menu_t *menu)
+{
+    return menu->current_dialcode_selection;
+}
+
+void menu_set_dialcode_selection(menu_t *menu, int sel)
+{
+    menu->current_dialcode_selection = sel;
+}
+
+void menu_set_dialcode_callback(menu_t *menu, int (dialcode_func)(menu_t *menu, void *param, int key, int sel))
+{
+    menu->dialcode_func = dialcode_func;
+}
+
+void menu_add_option(menu_t *menu, const char *name, int (callback_func)(menu_t *menu,void *param, int sel),
+                     int type, int num_options, char const **options, void *value_ptr)
 {
     int     i = menu->numoptions++;
 
@@ -167,7 +219,7 @@ void menu_add_option(menu_t *menu, char *name, int (callback_func)(menu_t *menu,
     menu->options[i].value_ptr = value_ptr;
 }
 
-void menu_add(menu_t *menu, char *name, int (*callback_func)(menu_t *menu,void *param, int sel))
+void menu_add(menu_t *menu, const char *name, int (*callback_func)(menu_t *menu,void *param, int sel))
 {
     int     i = menu->numoptions++;
 
@@ -182,11 +234,56 @@ void menu_add(menu_t *menu, char *name, int (*callback_func)(menu_t *menu,void *
 
 
 
+#ifdef HAVE_LIBXML2
+void menu_display_article(menu_t *menu)
+{
+    char          buf[256];
+    const char   *extra;
+    render_t     *render = menu->render;
+    int           row;
+    int           i;
+    int           last;
+
+    while ( menu->child ) {
+        menu = menu->child;
+    }
+
+    render_set_bgcol(render,BLACK);
+    render_clear(render);
+
+    snprintf(buf,sizeof(buf)," %s\n",menu->title ? menu->title : "");
+    render_set_bgcol(render,CYAN);
+    render_set_fgcol(render,BLACK);
+    render_printrow(render,0,buf);
+
+    /* Calculate how many rows to print */
+    last = (menu->top_offset + MENU_ROWS(menu) < menu->numoptions) 
+        ? menu->top_offset + MENU_ROWS(menu) : menu->numoptions;
+    for ( row = 2, i = menu->top_offset; i < last; i++, row++ ) {
+        if ( menu->options[i].type == MENU_INT ) {
+            extra = menu->options[i].options[*((int *)menu->options[i].value_ptr)];
+        } else {
+            extra = "";
+        }
+        if ( i < 9 && menu->flags & MENU_NUMBERS ) {
+            snprintf(buf,sizeof(buf)," %d. %s %s\n",i+1,menu->options[i].name,extra);
+        } else {
+            snprintf(buf,sizeof(buf),"   %s %s\n",menu->options[i].name,extra);
+        }      
+
+        render_set_bgcol(render,BLACK);
+        render_set_fgcol(render,WHITE);
+        render_printrow(render,row,buf);
+    }
+
+    program_register_keys(menu->program,REGISTER_MENU,menu_keys,menu);
+}
+#endif
 
 void menu_display(menu_t *menu)
 {
     char          buf[256];
-    char         *extra;
+    const char   *extra;
     render_t     *render = menu->render;
     int           row;
     int           i;
@@ -271,7 +368,7 @@ void menu_display(menu_t *menu)
         }
     }
         
-    app_register_keys(menu->app,REGISTER_MENU,menu_keys,menu);
+    program_register_keys(menu->program,REGISTER_MENU,menu_keys,menu);
 }
 
 
@@ -290,8 +387,11 @@ static int menu_keys(void *ptr, int code)
 
 
     /* If we're in streaming mpeg mode, then we'd like to change channels
-       without going back to the menu 
+       without going back to the menu - this is handled at a different
+       level by the plugin since it has to do some fancy work in working
+       out channel+ / channel-
     */
+#ifndef VDR_PLUGIN
     if ( streamtype == ( MEDIA_MPEG | MEDIA_LIVE ) ) {
         switch ( code ) {
         case keyChanUp:
@@ -336,6 +436,7 @@ static int menu_keys(void *ptr, int code)
         }
         return 0;
     }
+#endif
 
 
 
@@ -403,7 +504,15 @@ static int menu_keys(void *ptr, int code)
                 parent->child = NULL;        
             }      
             menu_display(parent);
+        } else {
+            int (*dialfunc)(menu_t *menu, void *param, int key, int sel);
+            dialfunc = menu->dialcode_func;
 
+            if(dialfunc) {    
+                menu->current_selection = dialfunc(menu, menu->param, 0, menu->current_selection);
+                menu->top_offset = menu->current_selection;
+                menu_display(menu);
+            }
         }
         break;
     case keyBack:
@@ -449,13 +558,12 @@ static int menu_keys(void *ptr, int code)
             if ( func && func(menu,menu->param,menu->current_selection) == 0 ) {
                 parent = menu->parent;
                 delete_menu(menu);
-                parent->child = NULL;        
                 menu_display(parent);
             }        
         }
         break;
-    case key1 ... key9:
-        if ( menu->flags & MENU_NUMBERS ) {
+    case key0 ... key9:
+        if ( (menu->flags & MENU_NUMBERS) && (code > key0) ) {
             pos = code - key1;
             if ( pos < menu->numoptions && menu->options ) {
                 func = menu->options[pos].callback_func;
@@ -463,7 +571,18 @@ static int menu_keys(void *ptr, int code)
                     delete_menu(menu);
                 }
             }
+        } else {
+            int (*dialfunc)(menu_t *menu, void *param, int key, int sel);
+
+            dialfunc = menu->dialcode_func;
+            if ( dialfunc ) {        
+                menu->current_selection = dialfunc(menu, menu->param, code, menu->current_selection);
+                menu->top_offset = menu->current_selection;
+                menu_display(menu);
+            }
+	    
         }
+
         break;
     case keyRed ... keyBlue:
         cfunc = menu->colour_func;        
@@ -471,12 +590,11 @@ static int menu_keys(void *ptr, int code)
             menu_t *parent;
             parent = menu->parent;
             delete_menu(menu);
-            parent->child = NULL;        
             menu_display(parent);
         }     
         break;
     default:
-        printf("Received IR code %d - not used here\n",code);
+        Dprintf(INFO,"Received IR code %d - not used here\n",code);
     }
     return 0;
 }
@@ -506,10 +624,10 @@ void menu_set_param_clearup(menu_t *menu, void (*clearup)(void *ptr))
  *                 pressed
  */
 void menu_set_colour_actions(menu_t *menu,
-                             char   *red,
-                             char   *green,
-                             char   *yellow,
-                             char   *blue,
+                             const char   *red,
+                             const char   *green,
+                             const char   *yellow,
+                             const char   *blue,
                              int   (*func)(menu_t *menu,void *param, int key, int sel))
 {
     int     i;
@@ -537,9 +655,16 @@ void menu_set_colour_actions(menu_t *menu,
     menu->colour_func = func;
 }
 
-#ifdef __cplusplus
+menu_t  *menu_parent(menu_t *menu)
+{
+    return menu->parent;
 }
-#endif
+
+menu_t  *menu_child(menu_t *menu)
+{
+    return menu->child;
+}
+
 
 
  
