@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: menuapp.c,v 1.47 2004/05/22 14:40:09 dom Exp $
- *   $Date: 2004/05/22 14:40:09 $
+ *   $Id: menuapp.c,v 1.49 2004/07/26 21:05:45 dom Exp $
+ *   $Date: 2004/07/26 21:05:45 $
  *
  *
  *   Implements the application
@@ -41,6 +41,7 @@ typedef struct {
 
 #define FILE_DIR    1
 #define FILE_URL    2
+#define FILE_URLDIR 4
 
 
 struct _menuapp {
@@ -63,6 +64,9 @@ typedef struct {
     menuapp_t  *menuapp;
     char       *path;
     char       *title;
+#ifdef VDR_PLUGIN
+    int        level;
+#endif
     /* For handling scanning of directories */
     int         filelist_num;
     filelist_t *filelist;
@@ -665,7 +669,7 @@ static int process_media(menu_t *menu,void *imenuapp, int sel)
         program_register_keys(dirlist->menuapp->program,REGISTER_MEDIA,media_keys,dirlist->menuapp);
         program_register_ack(dirlist->menuapp->program,REGISTER_MEDIA,media_ack,dirlist->menuapp);
         return 1;
-    } if ( entry->flags & FILE_DIR ) {
+    } else if ( entry->flags & FILE_DIR ) {
         /* The selection was a directory - we need to create a new menu - hah! */
         dirlist2 = new_dirlist(dirlist->menuapp);
 
@@ -687,7 +691,12 @@ static int process_media(menu_t *menu,void *imenuapp, int sel)
         menu_set_colour_actions(child,tr("Back"),tr("Play dir"),tr("Play list"), NULL, media_colour_keys);
 
         menu_display(child);
-        return 1;        
+        return 1; 
+#ifdef VDR_PLUGIN
+    } else if ( entry->flags & FILE_URLDIR ) {
+        recordings_submenu(menu,dirlist->menuapp,entry->url,dirlist->level);
+        return 1;
+#endif       
     } else {
         int filetype;
         /* It was a file, quick get the file type */
@@ -1014,14 +1023,14 @@ static int media_keys(void *ptr, int code)
         dongle_send_message(menuapp->dongle,RDC_MUTE);
         break;
     case keyFastFwd:
-        if (  ( streamtype & MEDIA_LIVE ) == 0 ) {
+        if (  ( streamtype & MEDIA_LIVE ) == 0 && (( streamtype & MEDIA_MASK) == MEDIA_MPEG ) ) {
             dongle_send_message(menuapp->dongle,RDC_FORWARD);
         } else {
             return 0;   /* Continue with the menus */
         }
         break;
     case keyFastRew:
-        if (  ( streamtype & MEDIA_LIVE ) == 0 ) {
+        if (  ( streamtype & MEDIA_LIVE ) == 0 && (( streamtype & MEDIA_MASK) == MEDIA_MPEG ) ) {
             dongle_send_message(menuapp->dongle,RDC_REWIND);
         } else {
             return 0;   /* Continue with the menus */
@@ -1108,7 +1117,7 @@ static int media_ack(int acktype, void *param, unsigned char *buf, int len)
         break;
     case RDC_FORWARD:
     case RDC_REWIND:
-        dongle_send_play(menuapp->dongle,menuapp->current_media);
+        //   dongle_send_play(menuapp->dongle,menuapp->current_media);
         break;
     default:
         return 0;    /* Kick it up a level */
