@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: mvplive.c,v 1.2 2004/05/22 16:41:27 dom Exp $
- *   $Date: 2004/05/22 16:41:27 $
+ *   $Id: mvplive.c,v 1.3 2004/05/24 19:35:45 dom Exp $
+ *   $Date: 2004/05/24 19:35:45 $
  *
  *
  *   Handle the mvplive:// URL type
@@ -86,9 +86,9 @@ void *cMvpLiveURL::Open(char *name, int *type, fops_t **fops, readready_cb cb, v
     URLInstance->cb_ptr = cb_ptr;
 
     if ( strncmp(name,"mvplive://",strlen("mvplive://")) == 0 ) {
-        *type = MEDIA_MPEG | MEDIA_LIVE | MEDIA_SOCKET;
+        *type = MEDIA_MPEG | MEDIA_LIVE;
     } else {
-        *type = MEDIA_MP3 | MEDIA_LIVE | MEDIA_SOCKET;
+        *type = MEDIA_MP3 | MEDIA_LIVE ;
     }
 
     URLInstance->event = (struct event *)malloc(sizeof(struct event));
