@@ -1,8 +1,8 @@
 /*
  *  MediaMVP Output Device for VDR
  *
- *  $Id: mvpwrap.h,v 1.1 2004/04/25 16:35:46 dom Exp $ 
- *  $Date: 2004/04/25 16:35:46 $
+ *  $Id: mvpwrap.h,v 1.2 2004/05/22 16:41:27 dom Exp $ 
+ *  $Date: 2004/05/22 16:41:27 $
  *
  *  This wraps up the real device in a redirecting layer
  *
@@ -43,7 +43,9 @@ public:
     virtual void SetVolumeDevice(int Volume);
 
     virtual bool Poll(cPoller &Poller, int TimeoutMs = 0);
+#if VDRVERSNUM < 10307
     virtual cOsdBase *NewOsd(int x, int y);
+#endif
 };
 
 #endif // MVPWRAP_H
