@@ -3,14 +3,14 @@
  *
  * See the README file for copyright information and how to reach the author.
  *
- * $Id: i18n.c,v 1.4 2004/02/22 15:38:31 dom Exp $
+ * $Id: i18n.c,v 1.9 2004/05/11 20:02:54 dom Exp $
  */
 
 #include "i18n.h"
 
 const tI18nPhrase Phrases[] = {
     { "Start MediaMVP Server",        // English
-      "",                             // Deutsch
+      "Starte MediaMVP Server",       // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -30,7 +30,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "MediaMVP GUI Port",            // English
-      "",                             // Deutsch
+      "MediaMVP GUI Port",            // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -50,7 +50,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "MediaMVP Stream Port",         // English
-      "",                             // Deutsch
+      "MediaMVP Stream Port",         // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -70,7 +70,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
    { "MediaMVP dongle.bin version",   // English
-      "",                             // Deutsch
+      "MediaMVP dongle.bin Version",  // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -90,7 +90,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
    { "Total Screen Width",            // English
-      "",                             // Deutsch
+      "Gesamte Bildschirm Breite",    // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -110,7 +110,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
    { "Total Screen Depth",            // English
-      "",                             // Deutsch
+      "Gesamte Bildschirm Hhe",      // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -130,7 +130,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
    { "GUI Screen Width",              // English
-      "",                             // Deutsch
+      "Userinterface Breite",         // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -150,7 +150,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
    { "GUI Screen Depth",              // English
-      "",                             // Deutsch
+      "Userinterface Hhe",           // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -170,7 +170,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "MediaMVP",                     // English
-      "",                             // Deutsch
+      "MediaMVP",                     // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -190,7 +190,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "Channels",                     // English
-      "",                             // Deutsch
+      "Kanle",                       // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -210,7 +210,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "Internet Radio",               // English
-      "",                             // Deutsch
+      "Internet Radio",               // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -229,8 +229,8 @@ const tI18nPhrase Phrases[] = {
       ""                              // Russian
 #endif
     },
-    { "Recordings",                     // English
-      "",                             // Deutsch
+    { "Other Videos",                 // English
+      "Andere Videos",                // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -250,7 +250,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "Music",                        // English
-      "",                             // Deutsch
+      "Musik",                        // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -270,7 +270,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "Settings",                     // English
-      "",                             // Deutsch
+      "Einstellungen",                // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -290,7 +290,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "NTSC",                         // English
-      "",                             // Deutsch
+      "NTSC",                         // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -310,7 +310,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "PAL",                          // English
-      "",                             // Deutsch
+      "PAL",                          // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -330,7 +330,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "None",                         // English
-      "",                             // Deutsch
+      "Kein",                         // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -350,7 +350,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
    { "Low",                           // English
-      "",                             // Deutsch
+      "Wenig",                        // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -370,7 +370,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
    { "Medium",                        // English
-      "",                             // Deutsch
+      "Mittel",                       // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -390,7 +390,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "High",                         // English
-      "",                             // Deutsch
+      "Hoch",                         // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -410,7 +410,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "RGB Detected",                 // English
-      "",                             // Deutsch
+      "RGB Festgestellt",             // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -430,7 +430,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "SVideo",                       // English
-      "",                             // Deutsch
+      "SVideo",                       // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -450,7 +450,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "Composite",                    // English
-      "",                             // Deutsch
+      "Composite",                    // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -470,7 +470,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "RGB/Composite",                // English
-      "",                             // Deutsch
+      "RGB/Composite",                // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -490,7 +490,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "TV Mode:",                     // English
-      "",                             // Deutsch
+      "TV Modus:",                    // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -510,7 +510,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "Output:",                      // English
-      "",                             // Deutsch
+      "Ausgabe:",                     // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -530,7 +530,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "Flicker Control:",             // English
-      "",                             // Deutsch
+      "Flimmerkontrolle",             // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -550,7 +550,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "Aspect Ratio:",                // English
-      "",                             // Deutsch
+      "Seitenverhltnis:",            // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -570,7 +570,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "Cancel changes",               // English
-      "",                             // Deutsch
+      "nderungen verwerfen",         // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -590,7 +590,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "Save settings (may take a while)",  // English
-      "",                             // Deutsch
+      "Einstellungen speichern (kann etwas dauern)",  // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -610,7 +610,7 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "Play list",                    // English
-      "",                             // Deutsch
+      "Liste spielen",                // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
       "",                             // Nederlands
@@ -630,6 +630,106 @@ const tI18nPhrase Phrases[] = {
 #endif
     },
     { "Play dir",                     // English
+      "Verz. spielen",                  // Deutsch
+      "",                             // Slovenski
+      "",                             // Italiano
+      "",                             // Nederlands
+      "",                             // Portugus
+      "",                             // Franais
+      "",                             // Norsk
+      "",                             // Suomi
+      "",                             // Polski
+      "",                             // Espaol
+      "",                             // Ellinika
+      "",                             // Svenska
+      "",                             // Romaneste
+      "",                             // Magyar
+      "",                             // Catala
+#if VDRVERSNUM >= 10300
+      ""                              // Russian
+#endif
+    },
+    { "Debug Level",                  // English
+      "Debug Level",                  // Deutsch
+      "",                             // Slovenski
+      "",                             // Italiano
+      "",                             // Nederlands
+      "",                             // Portugus
+      "",                             // Franais
+      "",                             // Norsk
+      "",                             // Suomi
+      "",                             // Polski
+      "",                             // Espaol
+      "",                             // Ellinika
+      "",                             // Svenska
+      "",                             // Romaneste
+      "",                             // Magyar
+      "",                             // Catala
+#if VDRVERSNUM >= 10300
+      ""                              // Russian
+#endif
+    },
+    { "Pictures",                     // English
+      "Bilder",                       // Deutsch
+      "",                             // Slovenski
+      "",                             // Italiano
+      "",                             // Nederlands
+      "",                             // Portugus
+      "",                             // Franais
+      "",                             // Norsk
+      "",                             // Suomi
+      "",                             // Polski
+      "",                             // Espaol
+      "",                             // Ellinika
+      "",                             // Svenska
+      "",                             // Romaneste
+      "",                             // Magyar
+      "",                             // Catala
+#if VDRVERSNUM >= 10300
+      ""                              // Russian
+#endif
+    },
+    { "News Feeds",                   // English
+      "Schlagzeilen",                 // Deutsch
+      "",                             // Slovenski
+      "",                             // Italiano
+      "",                             // Nederlands
+      "",                             // Portugus
+      "",                             // Franais
+      "",                             // Norsk
+      "",                             // Suomi
+      "",                             // Polski
+      "",                             // Espaol
+      "",                             // Ellinika
+      "",                             // Svenska
+      "",                             // Romaneste
+      "",                             // Magyar
+      "",                             // Catala
+#if VDRVERSNUM >= 10300
+      ""                              // Russian
+#endif
+    },
+    { "Screensaver Enabled",          // English
+      "Bildschirmschoner An",         // Deutsch
+      "",                             // Slovenski
+      "",                             // Italiano
+      "",                             // Nederlands
+      "",                             // Portugus
+      "",                             // Franais
+      "",                             // Norsk
+      "",                             // Suomi
+      "",                             // Polski
+      "",                             // Espaol
+      "",                             // Ellinika
+      "",                             // Svenska
+      "",                             // Romaneste
+      "",                             // Magyar
+      "",                             // Catala
+#if VDRVERSNUM >= 10300
+      ""                              // Russian
+#endif
+    },
+   { "Switch standards",              // English
       "",                             // Deutsch
       "",                             // Slovenski
       "",                             // Italiano
@@ -651,3 +751,5 @@ const tI18nPhrase Phrases[] = {
     },
     { NULL }
 };
+
+const char *debug_levels[] = { "MOO", "DEBUG", "INFO", "ERROR" };
