@@ -4,8 +4,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: menuapp-vdr.c,v 1.5 2004/05/22 15:11:18 dom Exp $
- *   $Date: 2004/05/22 15:11:18 $
+ *   $Id: menuapp-vdr.c,v 1.8 2004/07/27 19:11:27 dom Exp $
+ *   $Date: 2004/07/27 19:11:27 $
  *
  *
  *   Contains vdr specific functionality for the menuapp
@@ -21,10 +21,12 @@
 #include <vdr/recording.h>
 #endif
 
+static void        recordings_submenu(menu_t *menu, menuapp_t *menuapp, char *base, int level);
+static int         channels_colour_keys(menu_t *menu, void *imenuapp, int key, int sel);
+static int         schedule_colour_keys(menu_t *menu, void *imenuapp, int key, int sel);
+static int         vdrrecs_colour_keys(menu_t *menu, void *imenuapp, int key, int sel);
 
-static int    channels_colour_keys(menu_t *menu, void *imenuapp, int key, int sel);
-static int    schedule_colour_keys(menu_t *menu, void *imenuapp, int key, int sel);
-static int    vdrrecs_colour_keys(menu_t *menu, void *imenuapp, int key, int sel);
+static filelist_t *recordings_scan(char *base, int level, int *num);
 
 /***********************
  *
@@ -339,53 +341,185 @@ static int schedule_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
  ***********************/
 static int menuapp_vdrrecs(menu_t *menu,void *imenuapp, int sel)
 {
-    menuapp_t      *menuapp = (menuapp_t *)imenuapp;
+    recordings_submenu(menu,(menuapp_t *)imenuapp,NULL,-1);
+
+    return 1;
+
+}
+
+
+static void recordings_submenu(menu_t *menu, menuapp_t *menuapp, char *base, int level)
+{
     menu_t         *child;
     dirlist_t      *dirlist;
     filelist_t     *list = NULL;
-    int             num  = 0;
-    char            buf[1024];
-    char            buf2[1024];
-    cRecordings     Recordings;
-
+    char           *dirname = NULL;
+    int             i;
+  
     /* Define a menu */
     dirlist = new_dirlist(menuapp);
+
+    if ( base == NULL ) {
+        dirlist->level = -1;
+    } else {
+        if ( level == -1 ) {
+	    level = 0;
+        }
+        dirlist->level = ++level;
+    }
+
     child = new_menu(menuapp->dongle,menuapp->render,menuapp->program,menu,dirlist,0);
     menu_set_param_clearup(child,delete_dirlist);
-
-    menu_set_title(child,tr("Video Recordings"));   
-    menu_set_dialcode_callback(child, dial_entry);
-
-    /* Load recordings up from the VDR core */
-    bool recordings = Recordings.Load();
-
-    /* Thanks Sascha! - code taken from streamdev-server */
-    if ( recordings ) {
-        cRecording *recording = Recordings.First();
-        while ( recording ) {
-            
-            snprintf(buf,sizeof(buf),"%s",recording->Title(' ',true));
-            snprintf(buf2,sizeof(buf2),"%s%s",VDRRECURL,buf);
-            
-            list = filelist_add(list,&num,buf,buf2,NULL,FILE_URL);
-            menu_add(child,buf,process_media);
-          
-            recording = Recordings.Next(recording);
+    
+    if ( base ) {
+        if ( ( dirname = strrchr(base,'~') ) == NULL ) {
+            dirname = base;
+        } else {
+            dirname++;
         }
     }
-   
+
+
+    menu_set_title(child,dirname ? dirname : tr("Video Recordings"));   
+    menu_set_dialcode_callback(child, dial_entry);
+
+    list = recordings_scan(base,dirlist->level,&dirlist->filelist_num);
+
     /* Now we'll set up dirlist */
-    dirlist->title = NULL;    /* We don't need it since there's no subdirs */
-    dirlist->path  = NULL;    /* We don't need it sinec there's no subdirs */
-    dirlist->filelist_num = num;
+    dirlist->title = NULL;    
+    dirlist->path  = NULL;    
     dirlist->filelist = list;
-   
+
+    for ( i = 0; i <  dirlist->filelist_num; i++ ) {
+        menu_add(child,dirlist->filelist[i].display_name,process_media);
+    }
+
     menu_set_colour_actions(child,tr("Back"),NULL,NULL,NULL,vdrrecs_colour_keys);
 
     menu_display(child);
-    return 1;  
+    return;  
 }
 
+/** \brief Scan the VDR recordings list 
+ *
+ *  \param base The subdirectory that we are browsing
+ *  \param level The subdirectory level that we're browsing at
+ *  \param num Pointer to keep the number of files added
+ *
+ * base should be NULL and level -1 when browsing the root directory
+ *
+ * This code is dirty to say the least...
+ */
+static filelist_t *recordings_scan(char *base, int level, int *num)
+{
+    char            buf[1024];
+    char            buf2[1024];
+    char           *lastitem = NULL;
+    int             lastcount = 0;
+    int             lastnew = 0;
+    char           *dirname;
+    char           *ptr;
+    filelist_t     *list = NULL;
+    int             lev,tlevel;
+    cRecordings     Recordings;
+
+    tlevel = level < 0 ? 0 : level;
+
+    bool recordings = Recordings.Load();
+
+    if ( recordings ) {
+        cRecording *recording = Recordings.First();
+        while ( recording ) {
+            if ( base == NULL || (strstr(recording->Name(),base) == recording->Name() && recording->Name()[strlen(base)] == '~') ) {
+                                
+                snprintf(buf,sizeof(buf),"%s",recording->Name());                
+                lev = 0;
+                ptr = buf;
+                while ( *ptr ) {
+                    if ( *ptr == '~' ) {
+                        if ( lev == tlevel ) {
+                            *ptr = 0;
+                        }
+                        lev++;
+                    }  
+                    ++ptr;
+                }
+
+                /* Recording at the current directory level */
+                if ( tlevel == lev  ) {
+                    /* Add any pending subdirectory */
+                    if ( lastitem ) {
+                        if ( ( dirname = strrchr(lastitem,'~') ) == NULL ) {
+                            dirname = lastitem;
+                        } else {
+                            dirname++;
+                        }
+                        snprintf(buf2,sizeof(buf2),"%d\t%d\t%s",lastcount,lastnew,dirname);
+                        list = filelist_add(list,num,buf2,lastitem,NULL,FILE_URLDIR);
+                        free(lastitem);
+                        lastitem = NULL;
+                    }
+                    /* Add in this new recording */
+                    snprintf(buf,sizeof(buf),"%s",recording->Title(' ',true,level));
+                    snprintf(buf2,sizeof(buf2),"%s%s",VDRRECURL,recording->Title(' ',true));
+                    list = filelist_add(list,num,buf,buf2,NULL,FILE_URL);
+                } else if ( lev == tlevel + 1 ) {  /* At one level down from where we're browsing */
+                    
+                    /* Same path as last time, add it into the list */
+                    if ( lastitem && strcmp(buf,lastitem) == 0 ) {
+                        lastcount++;
+                        if ( recording->IsNew() ) {
+                            lastnew++;
+                        }
+                    } else {
+                        /* A different item, so add in the previous subdirectory and start a new
+                           one
+                        */
+                        if ( lastitem ) {
+                            if ( ( dirname = strrchr(lastitem,'~') ) == NULL ) {
+                                dirname = lastitem;
+                            } else {
+                                dirname++;
+                            }
+                            snprintf(buf2,sizeof(buf2),"%d\t%d\t%s",lastcount,lastnew,dirname);
+                            list = filelist_add(list,num,buf2,lastitem,NULL,FILE_URLDIR);
+                            free(lastitem);
+                        }
+                        lastitem = strdup(buf);
+                        lastcount = 1;
+                        lastnew = recording->IsNew() ? 1 : 0;
+                    }
+                    /* Contained within a subdirectory of a subdirectory, increment the counters */
+                } else {
+                    lastcount++;
+                    if ( recording->IsNew() ) {
+                        lastnew++;
+                    }
+                }
+            }
+            recording = Recordings.Next(recording);
+        }
+    }
+
+
+    if ( lastitem ) {
+        if ( ( dirname = strrchr(lastitem,'~') ) == NULL ) {
+            dirname = lastitem;
+        } else {
+            dirname++;
+        }
+        snprintf(buf2,sizeof(buf2),"%d\t%d\t%s",lastcount,lastnew,dirname);
+        list = filelist_add(list,num,buf2,lastitem,NULL,FILE_URLDIR);
+        free(lastitem);
+    }
+
+ 
+
+    return list;
+}
+
+
+
 
 static int vdrrecs_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
 {
