@@ -3,8 +3,8 @@
  *
  *   (C) 2004 Dominic Morris
  *
- *   $Id: libmvp.h,v 1.26 2004/05/11 19:26:06 dom Exp $
- *   $Date: 2004/05/11 19:26:06 $
+ *   $Id: libmvp.h,v 1.33 2004/09/26 15:47:33 dom Exp $
+ *   $Date: 2004/09/26 15:47:33 $
  *
  *   This file contains all application accessible information
  */
@@ -83,17 +83,32 @@ extern int             dongle_get_lasttype(dongle_t *dongle);
 extern void            dongle_update_screen(dongle_t *dongle);
 extern char           *dongle_get_streamname(dongle_t *dongle);
 
-
 /* surface.c */
+
+/* Modes that we support */
+typedef enum {
+    MAP_YVU = 0,
+    MAP_RGB,
+    MAP_AYVU,
+    MAP_ARGB,
+} mapmode_t;
 extern surface_t      *surface_alloc(int width, int depth, int bpp);
 extern void            surface_dealloc(surface_t *surface);
 extern void            surface_clear(surface_t *surface, uint32_t rgb);
-extern void           *surface_rgb2yvuy(surface_t *surface);
-extern int             surface_get_yuvsize(surface_t *surface);
+extern void           *surface_map(surface_t *surface, mapmode_t mode, int *size);
 extern unsigned int    surface_get_pixel(surface_t *surface,int x, int y);
 extern void            surface_set_pixel(surface_t *surface, int x, int y, uint32_t rgb);
 extern int             surface_get_dirty(surface_t *surface);
 extern void            surface_set_dirty(surface_t *surface, int state);      
+extern void            surface_blit(surface_t *dest, surface_t *src, int delta_x, int delta_y, int width, int depth);
+extern int             surface_get_height(surface_t *surface);
+extern int             surface_get_width(surface_t *surface);
+
+/* Graphics routines - names may change? */
+extern void            surface_draw_rectangle(surface_t *sfc, int x1, int y1, int x2, int y2, uint32_t colour);
+extern void            surface_draw_ellipse(surface_t *sfc, int x1, int y1, int x2, int y2, uint32_t colour, int Quadrants);
+extern void            surface_draw_line(surface_t *sfc, int x0, int y0, int x1, int y1, uint32_t colour);
+extern void            surface_draw_round_rect(surface_t *sfc, int x, int y, int w, int d, int r, int t, uint32_t c, uint32_t b);
 
 
 /* stream.c */
@@ -135,7 +150,13 @@ struct _fops {
 #define URLFILE_MP3TAG      4
 #endif
 #define URLFILE_MPEG_FRAME_RATE 5
+#define URLFILE_IFRAME 6
 
+typedef struct {
+    int    count;
+    off_t  start;
+    size_t length;   
+} gopseek_t;
 
 
 /* Nasty function to determine info about playlists - check playlist.c for param details */
@@ -197,8 +218,8 @@ extern int        file_get_type_fd(int fd, unsigned char *buf);
 
 
 /* MP3 ID3 tag handling */
-#ifdef HAVE_LIBID3TAG
 typedef struct _mp3info  mp3info_t;
+#ifdef HAVE_LIBID3TAG
 extern mp3info_t      *new_mp3info();
 extern unsigned char  *mp3_get_title(mp3info_t *info);
 extern unsigned char  *mp3_get_artist(mp3info_t *info);
@@ -220,6 +241,24 @@ extern int             mpeg_get_height(mpeginfo_t *info);
 extern int             mpeg_get_rate_index(mpeginfo_t *info);
 extern void            delete_mpeg_info(mpeginfo_t *info);
 
+/* threading compatibility - bit basic! */
+#ifndef WIN32
+#include <pthread.h>
+
+typedef pthread_mutex_t mutex_t;
+#define mutex_init(m,a)  pthread_mutex_init(m,a)
+#define mutex_lock(m)    pthread_mutex_lock(m)
+#define mutex_unlock(m)  pthread_mutex_unlock(m)
+#define mutex_destroy(m) pthread_mutex_destroy(m)
+
+#else
+typedef void *mutex_t;
+#define mutex_init(m,a)
+#define mutex_lock(m)
+#define mutex_unlock(m)
+#define mutex_destroy(m)
+#endif
+
 
 #ifdef __cplusplus
 }
