@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: stream.c,v 1.34 2004/05/11 19:26:06 dom Exp $
- *   $Date: 2004/05/11 19:26:06 $
+ *   $Id: stream.c,v 1.38 2004/10/13 10:47:02 dom Exp $
+ *   $Date: 2004/10/13 10:47:02 $
  *
  *
  *   Handles the media stream socket..all a bit of mess at the moment..
@@ -156,7 +156,7 @@ static void stream_accept(int fd, short event, void *arg)
     stream_t           *stream;
     char               *hostname;
     int                 cfd;
-    int                 WRITEBUFSIZE = 200000;
+    int                 WRITEBUFSIZE = 2000;
 
     /* Reschedule event */
     event_add(ev,NULL);
@@ -402,7 +402,6 @@ static int media_block(stream_t *stream, unsigned char *buf, int len)
     if ( stream->mediatype & MEDIA_LIVE ) {
         if ( media->urlptr == NULL ) {
             /* The file has come to an end */
-            //printf("No more data...\n");
             stream_write_data(stream,TRUE);
             stream->pending_data = FALSE;
         } else if ( !media->start && ring_rest(&media->buffy) >= media->blocklen ) {
@@ -421,7 +420,11 @@ static int media_block(stream_t *stream, unsigned char *buf, int len)
     /* It's just a file on disc, no buffering needed */
     mlen = ring_write_file(&media->buffy,media->fops,media->urlptr,media->blocklen);
 
-    Dprintf(DEBUG, "%s sending block at %u ...\n", DEBUG_TIMESTAMP, media->offset);
+    if ( mlen < 0 ) {
+        mlen = 0;
+    }
+
+    Dprintf(DEBUG, "%s sending block at %u ... %d\n", DEBUG_TIMESTAMP, media->offset,mlen);
 
     ptr = buf + 8;
     INT32_TO_BUF(mlen,ptr);
@@ -432,6 +435,7 @@ static int media_block(stream_t *stream, unsigned char *buf, int len)
     write(stream->fd,buf,stream->min_msg_length);
     ring_read_file(&media->buffy,stream->fd,mlen);
 
+
     return stream->min_msg_length;
 }
 
@@ -452,6 +456,7 @@ static int media_seek(stream_t *stream, unsigned char *buf, int len)
     if ( (stream->mediatype & MEDIA_LIVE ) == 0 ) {
         ptr = buf + 8;
         BUF_TO_INT32(offset,ptr);
+        Dprintf(INFO,"Current offset is %d need %d\n",media->offset,offset);
 
         Dprintf(DEBUG, "%s seeking to %u ...\n", DEBUG_TIMESTAMP, offset);
         if ( media->fops->seek(media->urlptr,offset,SEEK_SET) > 0 ) {
@@ -480,42 +485,65 @@ static int media_8(stream_t *stream, unsigned char *buf, int len)
     return stream->min_msg_length;
 }
 
-
+/** \internal
+ *
+ *  \brief Handle a step message
+ *
+ *  \param stream Stream this message is associate dwith
+ *  \param buf The message
+ *  \param len Length of the message
+ *
+ *  This should only be called for non-streaming mpeg files
+ */
 static int media_step(stream_t *stream, unsigned char *buf, int len)
 {
     unsigned char *ptr;
     media_t       *media = &stream->media;
+    off_t          offset;
+    int            mlen;
+    gopseek_t      gop;
 
     /* Needs extending slightly... */
     if ( len < stream->min_msg_length ) {
         return 0;
     }
 
-    Dprintf(INFO,"Step received\n");
-    dump_hex(INFO,buf,stream->min_msg_length);
 
-    ptr = buf + 16;
-    INT32_TO_BUF(media->offset,ptr);
-
-#if 0
-    if ( buf[9] == 1 ) {  /* Forward */
-        media->offset += media->blocklen;
-    } else {              /* And back - but it doesn't work at the moment */
-        media->offset -= media->blocklen;
+    if ( buf[9] == 0x00 ) {
+        gop.count = -2;
+    } else {
+        gop.count = 1;
     }
 
-    if ( media->offset < 0 ) {
-        media->offset = 0;
-    } else if ( media->offset > media->filelength ) {
-        media->offset -= media->blocklen;
+    offset = media->fops->info(media->urlptr,URLFILE_IFRAME,&gop);
+   
+
+    if ( offset != -1 ) {
+        media->offset = gop.start;
+        media->fops->seek(media->urlptr,media->offset,SEEK_SET);
+        ring_clear(&media->buffy);
+        ptr = buf + 12;
+        INT32_TO_BUF(gop.length,ptr);
+        ptr = buf + 16;
+        INT32_TO_BUF(media->offset,ptr);
+        
+        Dprintf(DEBUG, "%s Step sending block at %u ... length %u\n", DEBUG_TIMESTAMP, media->offset,gop.length);
+        write(stream->fd,buf,stream->min_msg_length);
+            
+        /* It's just a file on disc, no buffering needed */
+        mlen = ring_write_file(&media->buffy,media->fops,media->urlptr,gop.length);
+        
+        
+        ring_read_file(&media->buffy,stream->fd,mlen);
+    } else {       
+        media->fops->seek(media->urlptr,media->offset,SEEK_SET); 
+        ptr = buf + 12;
+        INT32_TO_BUF(0,ptr);
+        ptr = buf + 16;
+        INT32_TO_BUF(media->offset,ptr);
+        write(stream->fd,buf,stream->min_msg_length);
     }
 
-    /* Nasty, possibly non portable bit... */
-    lseek(media->fd,media->offset,SEEK_SET);
-#endif
-
-    write(stream->fd,buf,stream->min_msg_length);
-
     return stream->min_msg_length;
 }
 
