@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: url_file.c,v 1.8 2004/05/11 19:26:06 dom Exp $
- *   $Date: 2004/05/11 19:26:06 $
+ *   $Id: url_file.c,v 1.9 2004/07/11 16:12:47 dom Exp $
+ *   $Date: 2004/07/11 16:12:47 $
  *
  *
  *   Deals with opening a file and fobbing off playlist detection
@@ -13,12 +13,6 @@
 
 #include "libmvp_internal.h"
 
-static void           *file_open(char *name, int *type, fops_t **fops_ptr, readready_cb cb, void *cb_ptr );
-static void            file_close(void *ptr);
-static off_t           file_seek(void *ptr, off_t offset, int whence);
-static int             file_read(void *ptr, unsigned char *buf, size_t buflen);
-static int             file_info(void *ptr, int cmd, void *dest);
-
 typedef struct {
     int            fd;
     char          *name;
@@ -28,6 +22,15 @@ typedef struct {
 
 } file_t;
 
+
+static void           *file_open(char *name, int *type, fops_t **fops_ptr, readready_cb cb, void *cb_ptr );
+static void            file_close(void *ptr);
+static off_t           file_seek(void *ptr, off_t offset, int whence);
+static int             file_read(void *ptr, unsigned char *buf, size_t buflen);
+static int             file_info(void *ptr, int cmd, void *dest);
+static int             file_gop_seek(file_t *file, gopseek_t *gop);
+
+
 static fops_t          file_fops = {
     NULL,
     file_open,
@@ -133,6 +136,7 @@ static int file_info(void *ptr, int cmd, void *dest)
 {
     file_t      *file = (file_t*)ptr;
     mpeginfo_t  *info = NULL;
+    gopseek_t   *gop = (gopseek_t *)dest;
 
     struct stat  sb;
 
@@ -159,11 +163,87 @@ static int file_info(void *ptr, int cmd, void *dest)
         *((int *)dest) = mpeg_get_rate_index(info);
         delete_mpeg_info(info);
         break;
+    case URLFILE_IFRAME:
+        /* Here we have to determine where the next iframe is */
+        return file_gop_seek(file,gop);
     default:
         return -1;
     }
     return 0;
 }
 
+static int file_gop_seek(file_t *file, gopseek_t *gop)
+{
+    unsigned char    buf[1024];
+    int     count =  1;
+    int     offset = 0;
+    int     i,r;
+    bool_t  seekstart = TRUE;
+    int     stepsize;
+
+    offset = lseek(file->fd,0,SEEK_CUR);
+
+    if ( gop->count < 0 ) {
+        stepsize = -sizeof(buf);
+        count = -gop->count;
+    } else {
+        stepsize = sizeof(buf);
+        count = gop->count;
+    }
+
+    while ( count > 0 && offset >= 0 ) {
+        lseek(file->fd,offset,SEEK_SET);
+        r = read(file->fd,buf,sizeof(buf));
+        if ( r <= 0 )
+            break;
+            
+        for ( i = 0; i < r - 3 ; i++ ) {
+            if ( seekstart == TRUE ) {
+                /* Seek sequence start code - this will contain an iframe */
+                if ( buf[i] == 0x00 && buf[i+1] == 0x00 && buf[i+2] == 0x01 && buf[i+3] == 0xb3 ) {
+                    if ( --count == 0 ) {
+                        gop->start = offset + i;
+                        count = 2; /* We need the second picture header */
+                        seekstart = FALSE;
+                        stepsize = sizeof(buf);
+                    }                            
+                }
+            } else {
+                /* Seek a picture header */
+                if ( buf[i] == 0x00 && buf[i+1] == 0x00 && buf[i+2] == 0x01 && buf[i+3] == 0x00 ) {
+                    if ( --count == 0 ) {
+                        gop->length = offset + i - gop->start;
+                    }
+                }
+            }
+        }    
+        if ( count != 0 ) {
+            if ( stepsize < 0 ) {
+                offset -= sizeof(buf);
+            } else {
+                offset += r;
+            }
+            /* If we go back to far, just go the start of the file and try again (going forwards) */
+            if ( offset < 0 ) {
+                count = 1;
+                offset = 0;
+                stepsize = sizeof(buf);
+            }
+        }
+    }
+    
+
+    if ( count != 0 ) {
+        return -1;
+    } 
+    return 0;
+}
+        
+        
+
+    
+
+
+
 
 
