@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: vdrrecurl.h,v 1.3 2004/05/07 19:31:00 dom Exp $
- *   $Date: 2004/05/07 19:31:00 $
+ *   $Id: vdrrecurl.h,v 1.4 2004/07/11 16:13:38 dom Exp $
+ *   $Date: 2004/07/11 16:13:38 $
  *
  *
  *   Handle the vdr:// URL type
@@ -29,12 +29,16 @@ public:
     cMediamvpVdrRecURL();
     ~cMediamvpVdrRecURL();
     static void Init();
-    static void *Open(char *name, int *type, fops_t **fops, readready_cb cb, void *cb_ptr);
-    static off_t Seek(void *ptr, off_t offset, int whence);
-    static void Close(void *ptr);
-    static int Read(void *ptr, unsigned char *buf, size_t buflen);
-    static void ReadEvent(int fd, short event, void *arg);
-    static int Info(void *ptr, int cmd, void *args);
+    static void *sOpen(char *name, int *type, fops_t **fops, readready_cb cb, void *cb_ptr);
+    static off_t sSeek(void *ptr, off_t offset, int whence);
+    static void sClose(void *ptr);
+    static int sRead(void *ptr, unsigned char *buf, size_t buflen);
+    static int sInfo(void *ptr, int cmd, void *args);
+    int GopSeek(gopseek_t *gop);
+    off_t Seek(off_t offset, int whence);
+    size_t Read(unsigned char *buf, size_t buflen);
+    off_t CurrentOffset();
+
 };
 
 #endif
