@@ -16,8 +16,8 @@ int main(int argc, char *argv[])
     
     window_dump_window(root);
 
-	/* Draw the box */
-	window_draw(root);
+	window_set_fill_col(box, 0xFF00FF);
+	printf("Box Fill Color: 0x%08X\n", window_get_fill_col(box));
 
     delete_window(root);
 
